#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_MULS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_MULS_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/muls.hpp>

#endif
